@@ -696,7 +696,7 @@ class SearchBar(RemappedInputLine):
         self.scroll()
 
         attr = 0
-        if len(self.text) == 0 and len(self.app.focus) > 0 and self.app.focus[-1] is not self:
+        if len(self.text) == 0 and (len(self.app.focus) == 0 or self.app.focus[-1] is not self):
             visible_text = tr('(no search active)')
             attr = self.app.color(common.SETTING_COL_INACTIVE)
         else:
